# swapwizard v.01 written for SAGE Live Pup - 700 MB s
# Mounts all Hard Disks and tries to find a pupswap.swp
# or alternativly a pagefile.sys on the drives (if not already enough Swapspace available)
# If no Swapfiles are found a pupswap.swp will be created on a Linux Partition
# feb 2010
# emil widmann at gmail com LGPL

LOWRAM=700000     # Gives Warning if lower RAM
BIGRAM=1500000    # Don't make Swapspace if more RAM than this
MINDISK=4194304   # Only makes a Swapfile if more Space on Disk than this
MINSWAP=1048576  # Size of Swapfile

# BUILD List which contains drives for swapspace in priority order and mount all Hard disk Partitions
# And mounts all Hard disks found
PARTS=`grep '[hs]d[a-z][0-9]' /proc/partitions | tr -s ' ' | cut -d' ' -f5 | tr '\n' ' '`
PARTLIST=`df /mnt/home | grep '/dev/*' | tr -s ' ' | cut -f 1 -d ' '` # first look for /mnt/home
echo $PARTLIST
for PART in $PARTS
do
	PARTLIST="$PARTLIST /dev/$PART"  # Build List of HD Partitions
	MNTPT=`df | grep "/dev/${PART}" | tr -s ' ' | cut -f 6 -d ' '`
	if [ -n "$MNTPT" ]					 # Mount all HD Partitions which are not already mounted
	then
	 echo $PART already mounted
	else 
	 echo mounting $PART
	 mkdir /mnt/$PART
	 mount /dev/$PART /mnt/$PART
	fi
done

echo $PARTLIST

RAMSIZE=`free | grep 'Mem:' | tr -s ' ' | cut -f 3 -d ' '` #total physical ram 
FREERAM=`free | grep 'Mem:' | tr -s ' ' | cut -f 5 -d ' '`
SWAPSIZE=`free | grep 'Swap:' | tr -s ' ' | cut -f 3 -d ' '`  #total Swap Space
FREESWAP=`free | grep 'Swap:' | tr -s ' ' | cut -f 5 -d ' '`

echo Memory status:
echo --------------
echo RAM Size:    $RAMSIZE KB
echo Free Ram:    $FREERAM KB
echo Swap Size:   $SWAPSIZE KB
echo Free Swap:   $FREESWAP KB
echo --------------
echo Structure of Swap Space BEFORE Wizard:
cat /proc/swaps	#prints the Swapfiles and Partitons
echo


# Print Warning if low RAM machine
if [ $RAMSIZE -lt $LOWRAM ]
then
	echo Warning: RAM memory below $LOWRAM KB, upgrade recommended!
fi

# only Do if Ram below 1.4 GB. Big RAM don't need SWAP
if [ $RAMSIZE -lt $BIGRAM ]
then
	for PART in $PARTLIST #for all mountpoints
	do
		# echo a $PART : Swapspace $SWAPSIZE # just for debugging
		if [ $SWAPSIZE -ge $[$MINSWAP-1000] ] # More then 1 GB swap is enough
		then
		  break
		fi  
		
		MNTPT=`df | grep "$PART" | tr -s ' ' | cut -f 6 -d ' '`                  # get the Mount point
		FREE=`df | grep "$PART" | tr -s ' ' | cut -f 4 -d ' '`					 # get Free Disk Space
		FS=`fdisk -l | grep "$PART" | tr -d '*' | tr -s ' ' | cut -f 6 -d ' '`   # Get The Filesystem
		
		# echo b Device: $PART - MountPoint: $MNTPT - Filesystem: $FS #for debugging
		# echo b Diskspace available: $FREE - Swapsize: $SWAPSIZE

		# LINUX PARTITIONS PART
		if [ $FS == "Linux" ] # check if Linux Partition
		then
			SWAPFILE="${MNTPT}/pupswap.swp" #pupswap.swp is autodetected by puppy in /mnt/home
			# echo c $SWAPFILE
			if [ -e $SWAPFILE ] # check if Swapfile exists
			then # if yes activate swapfile
			    echo c1
				mkswap $SWAPFILE 
				swapon $SWAPFILE
				FILESIZE=$(stat -c%s $SWAPFILE)
				echo $SWAPFILE already existed - Size: $FILESIZE KB - activated as swapfile! 
				if [ $FILESIZE -lt $MINSWAP ]
				then # 
					echo Recommended to increase Filsize to $[$MINSWAP/1024] MB! # is there a special reason for not mounteda small swapfile?
				fi
			else # Swapfile in Linuxpartition doesn't exist
				if [ $MINDISK -lt $FREE ] # just add swapfile if more then 4 GB free DiskSpace
				then # Commands to add a swapfile
					echo Creating $SWAPFILE ... please wait ...
					dd if=/dev/zero of=$SWAPFILE bs=1024 count=$[$MINSWAP/1024]k	
					mkswap $SWAPFILE
					swapon $SWAPFILE
					echo Created and activated $SWAPFILE with $[$MINSWAP/1024] MB Size!
				else
					echo Warning: no swapfile in $PART created. Free Disk Space below $[$MINDISK/1024] MB.
				fi # $DISKFREE -gt 419304 
			fi #  Swapfile exists?
		# WINDOWS PARTITON PART
		else # No Linux Partition, probably its Windows - 1. search for Pupswap.swp
			SWAPFILE="${MNTPT}/pupswap.swp"
			# echo d $SWAPFILE #just debug
			if [ -e $SWAPFILE ]
			then # if Swapfile exists, activate it
				mkswap $SWAPFILE 
				swapon $SWAPFILE
				FILESIZE=$(stat -c%s $SWAPFILE)
				echo $SWAPFILE already existed - Size: $[$FILESIZE/1024 MB] - activated as swapfile! 
				if [ $FILESIZE -lt $MINSWAP ]
				then  
					echo Recommended to increase Filsize to $[$MINSWAP/1024] MB! # Maybe there is a special reason for not mounteda small swapfile?
				fi
			else # if no pupswap.swp 2. try a windows pagefile Experimental
				SWAPFILE="${MNTPT}/pagefile.sys"
				# echo e $SWAPFILE #just debug
				if [ -e $SWAPFILE ]
				then # if Swapfile exists, activate it
					mkswap $SWAPFILE 
					swapon $SWAPFILE
					FILESIZE=$(stat -c%s $SWAPFILE)
					echo $SWAPFILE already existed - Size: $[$FILESIZE/1024] MB - activated as swapfile! 
					if [ $FILESIZE -lt $MINSWAP ]
					then  
						echo Recommended to increase Filsize to $[$MINSWAP/1024] MB! # Maybe there is a special reason for not mounteda small swapfile?
					fi
				else
					echo Neither pupswap.swp nor pagefile.sys found in $MNTPT.
				fi # Check if Swapfile pagefile.sys exists
			fi #check if pupswap.swp exists
		fi # Windows Partition			
		SWAPSIZE=`free | grep 'Swap:' | tr -s ' ' | cut -f 3 -d ' '`  #check total Swap Space after this		
	done # for loop over PARTLIST
else # enuff RAM found
	echo RAMSIZE greater 1.4 GB. Swapspace not mandatory. Add Swapspace manually if you wish!
fi # RAMSIZE < 1.4 GB

if [ $SWAPSIZE -lt $[$MINSWAP-1000] ]
then # Failed
	echo Warning! There is not enough swap spave - virtual memory - as planned.
	echo Programs might run satisfactory nevertheless, but there could be problems.
	echo Try to provide additional swap space manually. You can get help from the manual.
    echo Details: The wizard failed to allocate a minimume of $[$MINSWAP/1024] MB. 
	echo This can have various reasons.
	echo Maybe you have no hard disks at all. At least the wizard failed to mount them, which it should do.
	echo Or you have to little space on Linux partitions to create a proper swapfile. 
	echo In that case clean up your disks and free a minimum of $[$MINDISK/1024] MB on one partition.
	echo If you have Windows partitons you have also no pagefiles there.
	echo You could create a Pupswap.swp in a Windows partiton but you have to do it manually.
	echo Howto create a swapfile using Windows Tools:
	echo Reboot to Windows, start Cmd - this is the Commandline or Dos Window ...
	echo type: fsutil file createnew C:\pupswap.swp 1073 741 824 # Creates 1 GB Swapfile
	echo 
	echo ... then reboot to Linux ...		
fi # Fail Message

# Print the final result of the Swapwizard
echo
echo Structure of Swap Space AFTER Wizard:
cat /proc/swaps 

